import { checkIsInsideStringLiteral } from '../../../../utils/checkIsInsideStringLiteral.js';
import { removeCommentsFromTs } from '../../../../utils/removeCommentsFromTs.js';
import { checkHasDynamicUsage } from './utils/checkHasDynamicUsage.js';
export const findUnusedClasses = ({ cssClasses, tsContent, importNames, }) => {
    const unusedClasses = [];
    // Check for dynamic usage patterns
    if (checkHasDynamicUsage(tsContent, importNames)) {
        return { hasDynamicUsage: true, unusedClasses: null };
    }
    // Clean content from comments for accurate detection
    const cleanContent = removeCommentsFromTs(tsContent);
    for (const className of cssClasses) {
        const isUsed = importNames.some((importName) => {
            // Direct usage: importName.className
            const directUsageRegex = new RegExp(`\\b${importName}\\.${className}\\b`, 'g');
            // Bracket notation: importName['className'] or importName["className"]
            const bracketUsageRegex = new RegExp(`\\b${importName}\\s*\\[\\s*['"\`]${className}['"\`]\\s*\\]`, 'g');
            // Check direct usage
            let match = null;
            directUsageRegex.lastIndex = 0;
            while (true) {
                match = directUsageRegex.exec(cleanContent);
                if (match === null)
                    break;
                if (!checkIsInsideStringLiteral(cleanContent, match.index)) {
                    return true;
                }
            }
            // Check bracket usage
            bracketUsageRegex.lastIndex = 0;
            while (true) {
                match = bracketUsageRegex.exec(cleanContent);
                if (match === null)
                    break;
                if (!checkIsInsideStringLiteral(cleanContent, match.index)) {
                    return true;
                }
            }
            return false;
        });
        if (!isUsed) {
            unusedClasses.push(className);
        }
    }
    return { unusedClasses, hasDynamicUsage: false };
};
